@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2014 Jeffrey Stedfast
+ *  Copyright (C) 2000-2011 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -316,10 +316,6 @@ int main (int argc, char **argv)
 	
 	/* parse the message */
 	message = parse_message (fd);
-	if (message == NULL) {
-		printf("Error parsing message");
-		return 1;
-	}
 	
 	/* count the number of parts in the message */
 	count_parts_in_message (message);
