@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2010 Jeffrey Stedfast
+ *  Copyright (C) 2000-2011 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -39,167 +39,121 @@ extern int verbose;
 
 #define v(x) if (verbose > 3) x
 
-
-typedef struct _TestSession TestSession;
-typedef struct _TestSessionClass TestSessionClass;
-
-struct _TestSession {
-	GMimeSession parent_object;
-	
-};
-
-struct _TestSessionClass {
-	GMimeSessionClass parent_class;
-	
-};
-
-static void test_session_class_init (TestSessionClass *klass);
-
-static char *request_passwd (GMimeSession *session, const char *prompt,
-			     gboolean secret, const char *item,
-			     GError **err);
-
-
-static GMimeSessionClass *parent_class = NULL;
-
-
-static GType
-test_session_get_type (void)
+static gboolean
+request_passwd (GMimeCryptoContext *ctx, const char *user_id, const char *prompt_ctx, gboolean reprompt, GMimeStream *response, GError **err)
 {
-	static GType type = 0;
+	g_mime_stream_write_string (response, "no.secret\n");
 	
-	if (!type) {
-		static const GTypeInfo info = {
-			sizeof (TestSessionClass),
-			NULL, /* base_class_init */
-			NULL, /* base_class_finalize */
-			(GClassInitFunc) test_session_class_init,
-			NULL, /* class_finalize */
-			NULL, /* class_data */
-			sizeof (TestSession),
-			0,    /* n_preallocs */
-			NULL, /* object_init */
-		};
-		
-		type = g_type_register_static (GMIME_TYPE_SESSION, "TestSession", &info, 0);
+	return TRUE;
+}
+
+static GMimeSignatureStatus
+get_sig_status (GMimeSignatureList *signatures)
+{
+	GMimeSignatureStatus status = GMIME_SIGNATURE_STATUS_GOOD;
+	GMimeSignature *sig;
+	int i;
+	
+	if (!signatures || signatures->array->len == 0)
+		return GMIME_SIGNATURE_STATUS_ERROR;
+	
+	for (i = 0; i < g_mime_signature_list_length (signatures); i++) {
+		sig = g_mime_signature_list_get_signature (signatures, i);
+		status = MAX (status, sig->status);
 	}
 	
-	return type;
+	return status;
 }
 
-
 static void
-test_session_class_init (TestSessionClass *klass)
+print_verify_results (GMimeSignatureList *signatures)
 {
-	GMimeSessionClass *session_class = GMIME_SESSION_CLASS (klass);
+	GMimeSignature *sig;
+	int count, i;
 	
-	parent_class = g_type_class_ref (GMIME_TYPE_SESSION);
-	
-	session_class->request_passwd = request_passwd;
-}
-
-static char *
-request_passwd (GMimeSession *session, const char *prompt, gboolean secret, const char *item, GError **err)
-{
-	return g_strdup ("no.secret");
-}
-
-
-
-static void
-print_verify_results (const GMimeSignatureValidity *validity)
-{
-	GMimeSigner *signer;
-	
-	switch (validity->status) {
-	case GMIME_SIGNATURE_STATUS_NONE:
-		fputs ("NONE\n", stdout);
-		break;
+	switch (get_sig_status (signatures)) {
 	case GMIME_SIGNATURE_STATUS_GOOD:
 		fputs ("GOOD\n", stdout);
 		break;
 	case GMIME_SIGNATURE_STATUS_BAD:
 		fputs ("BAD\n", stdout);
 		break;
-	case GMIME_SIGNATURE_STATUS_UNKNOWN:
-		fputs ("Unknown status\n", stdout);
+	case GMIME_SIGNATURE_STATUS_ERROR:
+		fputs ("ERROR status\n", stdout);
 		break;
 	default:
 		fputs ("Unknown enum value\n", stdout);
 		break;
 	}
 	
-	fputs ("\nSigners:\n", stdout);
-	signer = validity->signers;
-	while (signer != NULL) {
-		fprintf (stdout, "\tName: %s\n", signer->name ? signer->name : "(null)");
-		fprintf (stdout, "\tKeyId: %s\n", signer->keyid ? signer->keyid : "(null)");
-		fprintf (stdout, "\tFingerprint: %s\n", signer->fingerprint ? signer->fingerprint : "(null)");
+	fputs ("\nSignatures:\n", stdout);
+	count = g_mime_signature_list_length (signatures);
+	for (i = 0; i < count; i++) {
+		sig = g_mime_signature_list_get_signature (signatures, i);
+		
+		fprintf (stdout, "\tName: %s\n", sig->cert->name ? sig->cert->name : "(null)");
+		fprintf (stdout, "\tKeyId: %s\n", sig->cert->keyid ? sig->cert->keyid : "(null)");
+		fprintf (stdout, "\tFingerprint: %s\n", sig->cert->fingerprint ? sig->cert->fingerprint : "(null)");
 		fprintf (stdout, "\tTrust: ");
 		
-		switch (signer->trust) {
-		case GMIME_SIGNER_TRUST_NONE:
+		switch (sig->cert->trust) {
+		case GMIME_CERTIFICATE_TRUST_NONE:
 			fputs ("None\n", stdout);
 			break;
-		case GMIME_SIGNER_TRUST_NEVER:
+		case GMIME_CERTIFICATE_TRUST_NEVER:
 			fputs ("Never\n", stdout);
-		case GMIME_SIGNER_TRUST_UNDEFINED:
+			break;
+		case GMIME_CERTIFICATE_TRUST_UNDEFINED:
 			fputs ("Undefined\n", stdout);
 			break;
-		case GMIME_SIGNER_TRUST_MARGINAL:
+		case GMIME_CERTIFICATE_TRUST_MARGINAL:
 			fputs ("Marginal\n", stdout);
 			break;
-		case GMIME_SIGNER_TRUST_FULLY:
+		case GMIME_CERTIFICATE_TRUST_FULLY:
 			fputs ("Fully\n", stdout);
 			break;
-		case GMIME_SIGNER_TRUST_ULTIMATE:
+		case GMIME_CERTIFICATE_TRUST_ULTIMATE:
 			fputs ("Ultimate\n", stdout);
 			break;
 		}
 		
 		fprintf (stdout, "\tStatus: ");
-		switch (signer->status) {
-		case GMIME_SIGNER_STATUS_NONE:
-			fputs ("None\n", stdout);
-			break;
-		case GMIME_SIGNER_STATUS_GOOD:
+		switch (sig->status) {
+		case GMIME_SIGNATURE_STATUS_GOOD:
 			fputs ("GOOD\n", stdout);
 			break;
-		case GMIME_SIGNER_STATUS_BAD:
+		case GMIME_SIGNATURE_STATUS_BAD:
 			fputs ("BAD\n", stdout);
 			break;
-		case GMIME_SIGNER_STATUS_ERROR:
+		case GMIME_SIGNATURE_STATUS_ERROR:
 			fputs ("ERROR\n", stdout);
 			break;
 		}
 		
-		fprintf (stdout, "\tSignature made on %s", ctime (&signer->created));
-		if (signer->expires != (time_t) 0)
-			fprintf (stdout, "\tSignature expires on %s", ctime (&signer->expires));
+		fprintf (stdout, "\tSignature made on %s", ctime (&sig->created));
+		if (sig->expires != (time_t) 0)
+			fprintf (stdout, "\tSignature expires on %s", ctime (&sig->expires));
 		else
 			fprintf (stdout, "\tSignature never expires\n");
 		
-		if (signer->errors) {
+		if (sig->errors) {
 			fprintf (stdout, "\tErrors: ");
-			if (signer->errors & GMIME_SIGNER_ERROR_EXPSIG)
+			if (sig->errors & GMIME_SIGNATURE_ERROR_EXPSIG)
 				fputs ("Expired, ", stdout);
-			if (signer->errors & GMIME_SIGNER_ERROR_NO_PUBKEY)
+			if (sig->errors & GMIME_SIGNATURE_ERROR_NO_PUBKEY)
 				fputs ("No Pub Key, ", stdout);
-			if (signer->errors & GMIME_SIGNER_ERROR_EXPKEYSIG)
+			if (sig->errors & GMIME_SIGNATURE_ERROR_EXPKEYSIG)
 				fputs ("Key Expired, ", stdout);
-			if (signer->errors & GMIME_SIGNER_ERROR_REVKEYSIG)
+			if (sig->errors & GMIME_SIGNATURE_ERROR_REVKEYSIG)
 				fputs ("Key Revoked", stdout);
 			fputc ('\n', stdout);
 		} else {
 			fprintf (stdout, "\tNo errors for this signer\n");
 		}
 		
-		if ((signer = signer->next))
+		if (i + 1 < count)
 			fputc ('\n', stdout);
 	}
-	
-	fprintf (stdout, "\nValidity diagnostics: \n%s\n",
-		 g_mime_signature_validity_get_details (validity));
 }
 
 #define MULTIPART_SIGNED_CONTENT "This is a test of the emergency broadcast system \
@@ -210,9 +164,9 @@ that GMime properly treats MIME part content as opaque.\nIf this still verifies
 then we have ourselves a winner I guess...\n"
 
 static void
-test_multipart_signed (GMimeCipherContext *ctx)
+test_multipart_signed (GMimeCryptoContext *ctx)
 {
-	GMimeSignatureValidity *validity;
+	GMimeSignatureList *signatures;
 	GMimeMultipartSigned *mps;
 	GMimeDataWrapper *content;
 	GMimeMessage *message;
@@ -247,7 +201,7 @@ test_multipart_signed (GMimeCipherContext *ctx)
 	
 	/* sign the part */
 	g_mime_multipart_signed_sign (mps, GMIME_OBJECT (part), ctx, "no.user@no.domain",
-				      GMIME_CIPHER_HASH_SHA1, &err);
+				      GMIME_DIGEST_ALGO_SHA1, &err);
 	g_object_unref (part);
 	
 	if (err != NULL) {
@@ -289,15 +243,15 @@ test_multipart_signed (GMimeCipherContext *ctx)
 	mps = (GMimeMultipartSigned *) message->mime_part;
 	
 	v(fputs ("Trying to verify signature... ", stdout));
-	if (!(validity = g_mime_multipart_signed_verify (mps, ctx, &err))) {
+	if (!(signatures = g_mime_multipart_signed_verify (mps, ctx, &err))) {
 		ex = exception_new ("%s", err->message);
 		v(fputs ("failed.\n", stdout));
 		g_error_free (err);
 		throw (ex);
 	}
 	
-	v(print_verify_results (validity));
-	g_mime_signature_validity_free (validity);
+	v(print_verify_results (signatures));
+	g_object_unref (signatures);
 	
 	g_object_unref (message);
 }
@@ -305,11 +259,11 @@ test_multipart_signed (GMimeCipherContext *ctx)
 #define MULTIPART_ENCRYPTED_CONTENT "This is a test of multipart/encrypted.\n"
 
 static void
-test_multipart_encrypted (GMimeCipherContext *ctx, gboolean sign)
+test_multipart_encrypted (GMimeCryptoContext *ctx, gboolean sign)
 {
-	const GMimeSignatureValidity *sv;
 	GMimeStream *cleartext, *stream;
 	GMimeMultipartEncrypted *mpe;
+	GMimeDecryptResult *result;
 	GMimeDataWrapper *content;
 	GMimeObject *decrypted;
 	GPtrArray *recipients;
@@ -344,7 +298,8 @@ test_multipart_encrypted (GMimeCipherContext *ctx, gboolean sign)
 	recipients = g_ptr_array_new ();
 	g_ptr_array_add (recipients, "no.user@no.domain");
 	g_mime_multipart_encrypted_encrypt (mpe, GMIME_OBJECT (part), ctx, sign,
-					    "no.user@no.domain", recipients, &err);
+					    "no.user@no.domain", GMIME_DIGEST_ALGO_SHA256,
+					    recipients, &err);
 	g_ptr_array_free (recipients, TRUE);
 	g_object_unref (part);
 	
@@ -388,7 +343,7 @@ test_multipart_encrypted (GMimeCipherContext *ctx, gboolean sign)
 	mpe = (GMimeMultipartEncrypted *) message->mime_part;
 	
 	/* okay, now to test our decrypt function... */
-	decrypted = g_mime_multipart_encrypted_decrypt (mpe, ctx, &err);
+	decrypted = g_mime_multipart_encrypted_decrypt (mpe, ctx, &result, &err);
 	if (!decrypted || err != NULL) {
 		ex = exception_new ("decryption failed: %s", err->message);
 		g_object_unref (cleartext);
@@ -396,17 +351,19 @@ test_multipart_encrypted (GMimeCipherContext *ctx, gboolean sign)
 		throw (ex);
 	}
 	
-	sv = g_mime_multipart_encrypted_get_signature_validity (mpe);
-	v(print_verify_results (sv));
+	if (result->signatures)
+		v(print_verify_results (result->signatures));
 	
 	if (sign) {
-		if (sv->status != GMIME_SIGNATURE_STATUS_GOOD)
-			ex = exception_new ("signature validity status expected to be GOOD");
+		if (!result->signatures || get_sig_status (result->signatures) != GMIME_SIGNATURE_STATUS_GOOD)
+			ex = exception_new ("signature status expected to be GOOD");
 	} else {
-		if (sv->status != GMIME_SIGNATURE_STATUS_NONE)
-			ex = exception_new ("signature validity status expected to be NONE");
+		if (result->signatures)
+			ex = exception_new ("signature status expected to be NONE");
 	}
 	
+	g_object_unref (result);
+	
 	if (ex != NULL) {
 		g_object_unref (cleartext);
 		throw (ex);
@@ -429,18 +386,18 @@ test_multipart_encrypted (GMimeCipherContext *ctx, gboolean sign)
 }
 
 static void
-import_key (GMimeCipherContext *ctx, const char *path)
+import_key (GMimeCryptoContext *ctx, const char *path)
 {
 	GMimeStream *stream;
 	GError *err = NULL;
 	Exception *ex;
 	int fd;
 	
-	if ((fd = open (path, O_RDONLY)) == -1)
-		throw (exception_new ("open() failed: %s", strerror (errno)));
+	if ((fd = open (path, O_RDONLY, 0)) == -1)
+		throw (exception_new ("open() failed: %s", g_strerror (errno)));
 	
 	stream = g_mime_stream_fs_new (fd);
-	g_mime_cipher_context_import_keys (ctx, stream, &err);
+	g_mime_crypto_context_import_keys (ctx, stream, &err);
 	g_object_unref (stream);
 	
 	if (err != NULL) {
@@ -453,8 +410,7 @@ import_key (GMimeCipherContext *ctx, const char *path)
 int main (int argc, char *argv[])
 {
 	const char *datadir = "data/pgpmime";
-	GMimeCipherContext *ctx;
-	GMimeSession *session;
+	GMimeCryptoContext *ctx;
 	struct stat st;
 	char *key;
 	int i;
@@ -481,9 +437,7 @@ int main (int argc, char *argv[])
 	
 	testsuite_start ("PGP/MIME implementation");
 	
-	session = g_object_new (test_session_get_type (), NULL);
-	
-	ctx = g_mime_gpg_context_new (session, "/usr/bin/gpg");
+	ctx = g_mime_gpg_context_new (request_passwd, "/usr/bin/gpg");
 	g_mime_gpg_context_set_always_trust ((GMimeGpgContext *) ctx, TRUE);
 	
 	testsuite_check ("GMimeGpgContext::import");
@@ -526,7 +480,6 @@ int main (int argc, char *argv[])
 		testsuite_check_failed ("multipart/encrypted+sign failed: %s", ex->message);
 	} finally;
 	
-	g_object_unref (session);
 	g_object_unref (ctx);
 	
 	testsuite_end ();
